==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosSpecFluentImpl<A extends PodHttpChaosSpecFluent<A>> extends BaseFluent<A> implements PodHttpChaosSpecFluent<A>{
  public PodHttpChaosSpecFluentImpl() {
  }
  public PodHttpChaosSpecFluentImpl(PodHttpChaosSpec instance) {
    this.withRules(instance.getRules()); 
  }
  private ArrayList<PodHttpChaosRuleBuilder> rules = new ArrayList<PodHttpChaosRuleBuilder>();
  public A addToRules(Integer index,PodHttpChaosRule item) {
    if (this.rules == null) {this.rules = new ArrayList<PodHttpChaosRuleBuilder>();}
    PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").add(index >= 0 ? index : _visitables.get("rules").size(), builder);this.rules.add(index >= 0 ? index : rules.size(), builder); return (A)this;
  }
  public A setToRules(Integer index,PodHttpChaosRule item) {
    if (this.rules == null) {this.rules = new ArrayList<PodHttpChaosRuleBuilder>();}
    PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);
    if (index < 0 || index >= _visitables.get("rules").size()) { _visitables.get("rules").add(builder); } else { _visitables.get("rules").set(index, builder);}
    if (index < 0 || index >= rules.size()) { rules.add(builder); } else { rules.set(index, builder);}
     return (A)this;
  }
  public A addToRules(io.fabric8.chaosmesh.v1alpha1.PodHttpChaosRule... items) {
    if (this.rules == null) {this.rules = new ArrayList<PodHttpChaosRuleBuilder>();}
    for (PodHttpChaosRule item : items) {PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").add(builder);this.rules.add(builder);} return (A)this;
  }
  public A addAllToRules(Collection<PodHttpChaosRule> items) {
    if (this.rules == null) {this.rules = new ArrayList<PodHttpChaosRuleBuilder>();}
    for (PodHttpChaosRule item : items) {PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").add(builder);this.rules.add(builder);} return (A)this;
  }
  public A removeFromRules(io.fabric8.chaosmesh.v1alpha1.PodHttpChaosRule... items) {
    for (PodHttpChaosRule item : items) {PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
  }
  public A removeAllFromRules(Collection<PodHttpChaosRule> items) {
    for (PodHttpChaosRule item : items) {PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromRules(Predicate<PodHttpChaosRuleBuilder> predicate) {
    if (rules == null) return (A) this;
    final Iterator<PodHttpChaosRuleBuilder> each = rules.iterator();
    final List visitables = _visitables.get("rules");
    while (each.hasNext()) {
      PodHttpChaosRuleBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodHttpChaosRule> getRules() {
    return rules != null ? build(rules) : null;
  }
  public List<PodHttpChaosRule> buildRules() {
    return rules != null ? build(rules) : null;
  }
  public PodHttpChaosRule buildRule(Integer index) {
    return this.rules.get(index).build();
  }
  public PodHttpChaosRule buildFirstRule() {
    return this.rules.get(0).build();
  }
  public PodHttpChaosRule buildLastRule() {
    return this.rules.get(rules.size() - 1).build();
  }
  public PodHttpChaosRule buildMatchingRule(Predicate<PodHttpChaosRuleBuilder> predicate) {
    for (PodHttpChaosRuleBuilder item: rules) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingRule(Predicate<PodHttpChaosRuleBuilder> predicate) {
    for (PodHttpChaosRuleBuilder item: rules) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRules(List<PodHttpChaosRule> rules) {
    if (this.rules != null) { _visitables.get("rules").removeAll(this.rules);}
    if (rules != null) {this.rules = new ArrayList(); for (PodHttpChaosRule item : rules){this.addToRules(item);}} else { this.rules = null;} return (A) this;
  }
  public A withRules(io.fabric8.chaosmesh.v1alpha1.PodHttpChaosRule... rules) {
    if (this.rules != null) {this.rules.clear();}
    if (rules != null) {for (PodHttpChaosRule item :rules){ this.addToRules(item);}} return (A) this;
  }
  public Boolean hasRules() {
    return rules != null && !rules.isEmpty();
  }
  public PodHttpChaosSpecFluent.RulesNested<A> addNewRule() {
    return new PodHttpChaosSpecFluentImpl.RulesNestedImpl();
  }
  public PodHttpChaosSpecFluent.RulesNested<A> addNewRuleLike(PodHttpChaosRule item) {
    return new PodHttpChaosSpecFluentImpl.RulesNestedImpl(-1, item);
  }
  public PodHttpChaosSpecFluent.RulesNested<A> setNewRuleLike(Integer index,PodHttpChaosRule item) {
    return new PodHttpChaosSpecFluentImpl.RulesNestedImpl(index, item);
  }
  public PodHttpChaosSpecFluent.RulesNested<A> editRule(Integer index) {
    if (rules.size() <= index) throw new RuntimeException("Can't edit rules. Index exceeds size.");
    return setNewRuleLike(index, buildRule(index));
  }
  public PodHttpChaosSpecFluent.RulesNested<A> editFirstRule() {
    if (rules.size() == 0) throw new RuntimeException("Can't edit first rules. The list is empty.");
    return setNewRuleLike(0, buildRule(0));
  }
  public PodHttpChaosSpecFluent.RulesNested<A> editLastRule() {
    int index = rules.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last rules. The list is empty.");
    return setNewRuleLike(index, buildRule(index));
  }
  public PodHttpChaosSpecFluent.RulesNested<A> editMatchingRule(Predicate<PodHttpChaosRuleBuilder> predicate) {
    int index = -1;
    for (int i=0;i<rules.size();i++) { 
    if (predicate.test(rules.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching rules. No match found.");
    return setNewRuleLike(index, buildRule(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodHttpChaosSpecFluentImpl that = (PodHttpChaosSpecFluentImpl) o;
    if (rules != null ? !rules.equals(that.rules) :that.rules != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rules,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rules != null && !rules.isEmpty()) { sb.append("rules:"); sb.append(rules); }
    sb.append("}");
    return sb.toString();
  }
  class RulesNestedImpl<N> extends PodHttpChaosRuleFluentImpl<PodHttpChaosSpecFluent.RulesNested<N>> implements PodHttpChaosSpecFluent.RulesNested<N>,Nested<N>{
    RulesNestedImpl(Integer index,PodHttpChaosRule item) {
      this.index = index;
      this.builder = new PodHttpChaosRuleBuilder(this, item);
    }
    RulesNestedImpl() {
      this.index = -1;
      this.builder = new PodHttpChaosRuleBuilder(this);
    }
    PodHttpChaosRuleBuilder builder;
    Integer index;
    public N and() {
      return (N) PodHttpChaosSpecFluentImpl.this.setToRules(index,builder.build());
    }
    public N endRule() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosSpecFluentImpl<A extends PodHttpChaosSpecFluent<A>> extends BaseFluent<A> implements PodHttpChaosSpecFluent<A>{
  public PodHttpChaosSpecFluentImpl() {
  }
  public PodHttpChaosSpecFluentImpl(PodHttpChaosSpec instance) {
    if (instance != null) {
      this.withRules(instance.getRules());
    }
  }
  private ArrayList<PodHttpChaosRuleBuilder> rules = new ArrayList<PodHttpChaosRuleBuilder>();
  public A addToRules(int index,PodHttpChaosRule item) {
    if (this.rules == null) {this.rules = new ArrayList<PodHttpChaosRuleBuilder>();}
    PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);
    if (index < 0 || index >= rules.size()) { _visitables.get("rules").add(builder); rules.add(builder); } else { _visitables.get("rules").add(index, builder); rules.add(index, builder);}
    return (A)this;
  }
  public A setToRules(int index,PodHttpChaosRule item) {
    if (this.rules == null) {this.rules = new ArrayList<PodHttpChaosRuleBuilder>();}
    PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);
    if (index < 0 || index >= rules.size()) { _visitables.get("rules").add(builder); rules.add(builder); } else { _visitables.get("rules").set(index, builder); rules.set(index, builder);}
    return (A)this;
  }
  public A addToRules(io.fabric8.chaosmesh.v1alpha1.PodHttpChaosRule... items) {
    if (this.rules == null) {this.rules = new ArrayList<PodHttpChaosRuleBuilder>();}
    for (PodHttpChaosRule item : items) {PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").add(builder);this.rules.add(builder);} return (A)this;
  }
  public A addAllToRules(Collection<PodHttpChaosRule> items) {
    if (this.rules == null) {this.rules = new ArrayList<PodHttpChaosRuleBuilder>();}
    for (PodHttpChaosRule item : items) {PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").add(builder);this.rules.add(builder);} return (A)this;
  }
  public A removeFromRules(io.fabric8.chaosmesh.v1alpha1.PodHttpChaosRule... items) {
    for (PodHttpChaosRule item : items) {PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
  }
  public A removeAllFromRules(Collection<PodHttpChaosRule> items) {
    for (PodHttpChaosRule item : items) {PodHttpChaosRuleBuilder builder = new PodHttpChaosRuleBuilder(item);_visitables.get("rules").remove(builder);if (this.rules != null) {this.rules.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromRules(Predicate<PodHttpChaosRuleBuilder> predicate) {
    if (rules == null) return (A) this;
    final Iterator<PodHttpChaosRuleBuilder> each = rules.iterator();
    final List visitables = _visitables.get("rules");
    while (each.hasNext()) {
      PodHttpChaosRuleBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodHttpChaosRule> getRules() {
    return rules != null ? build(rules) : null;
  }
  public List<PodHttpChaosRule> buildRules() {
    return rules != null ? build(rules) : null;
  }
  public PodHttpChaosRule buildRule(int index) {
    return this.rules.get(index).build();
  }
  public PodHttpChaosRule buildFirstRule() {
    return this.rules.get(0).build();
  }
  public PodHttpChaosRule buildLastRule() {
    return this.rules.get(rules.size() - 1).build();
  }
  public PodHttpChaosRule buildMatchingRule(Predicate<PodHttpChaosRuleBuilder> predicate) {
    for (PodHttpChaosRuleBuilder item: rules) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingRule(Predicate<PodHttpChaosRuleBuilder> predicate) {
    for (PodHttpChaosRuleBuilder item: rules) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withRules(List<PodHttpChaosRule> rules) {
    if (this.rules != null) { _visitables.get("rules").clear();}
    if (rules != null) {this.rules = new ArrayList(); for (PodHttpChaosRule item : rules){this.addToRules(item);}} else { this.rules = null;} return (A) this;
  }
  public A withRules(io.fabric8.chaosmesh.v1alpha1.PodHttpChaosRule... rules) {
    if (this.rules != null) {this.rules.clear(); _visitables.remove("rules"); }
    if (rules != null) {for (PodHttpChaosRule item :rules){ this.addToRules(item);}} return (A) this;
  }
  public Boolean hasRules() {
    return rules != null && !rules.isEmpty();
  }
  public PodHttpChaosSpecFluentImpl.RulesNested<A> addNewRule() {
    return new PodHttpChaosSpecFluentImpl.RulesNestedImpl();
  }
  public PodHttpChaosSpecFluentImpl.RulesNested<A> addNewRuleLike(PodHttpChaosRule item) {
    return new PodHttpChaosSpecFluentImpl.RulesNestedImpl(-1, item);
  }
  public PodHttpChaosSpecFluentImpl.RulesNested<A> setNewRuleLike(int index,PodHttpChaosRule item) {
    return new PodHttpChaosSpecFluentImpl.RulesNestedImpl(index, item);
  }
  public PodHttpChaosSpecFluentImpl.RulesNested<A> editRule(int index) {
    if (rules.size() <= index) throw new RuntimeException("Can't edit rules. Index exceeds size.");
    return setNewRuleLike(index, buildRule(index));
  }
  public PodHttpChaosSpecFluentImpl.RulesNested<A> editFirstRule() {
    if (rules.size() == 0) throw new RuntimeException("Can't edit first rules. The list is empty.");
    return setNewRuleLike(0, buildRule(0));
  }
  public PodHttpChaosSpecFluentImpl.RulesNested<A> editLastRule() {
    int index = rules.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last rules. The list is empty.");
    return setNewRuleLike(index, buildRule(index));
  }
  public PodHttpChaosSpecFluentImpl.RulesNested<A> editMatchingRule(Predicate<PodHttpChaosRuleBuilder> predicate) {
    int index = -1;
    for (int i=0;i<rules.size();i++) { 
    if (predicate.test(rules.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching rules. No match found.");
    return setNewRuleLike(index, buildRule(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosSpecFluentImpl that = (PodHttpChaosSpecFluentImpl) o;
    if (!java.util.Objects.equals(rules, that.rules)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rules,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rules != null) { sb.append("rules:"); sb.append(rules); }
    sb.append("}");
    return sb.toString();
  }
  class RulesNestedImpl<N> extends PodHttpChaosRuleFluentImpl<PodHttpChaosSpecFluentImpl.RulesNested<N>> implements PodHttpChaosSpecFluentImpl.RulesNested<N>,Nested<N>{
    RulesNestedImpl(int index,PodHttpChaosRule item) {
      this.index = index;
      this.builder = new PodHttpChaosRuleBuilder(this, item);
    }
    RulesNestedImpl() {
      this.index = -1;
      this.builder = new PodHttpChaosRuleBuilder(this);
    }
    PodHttpChaosRuleBuilder builder;
    int index;
    public N and() {
      return (N) PodHttpChaosSpecFluentImpl.this.setToRules(index,builder.build());
    }
    public N endRule() {
      return and();
    }
    
  }
  
}
